# mehen

**mehen** is a Rust command-line tool to analyze and extract information
from source codes written in multiple programming languages.
It is based on a parser generator tool and an incremental parsing library called
<a href="https://tree-sitter.github.io/tree-sitter/" target="_blank">Tree Sitter</a>.

You can find the source code of this software on
<a href="https://github.com/ophidiarium/mehen/" target="_blank">GitHub</a>,
while issues and feature requests can be posted on the respective
<a href="https://github.com/ophidiarium/mehen/issues/" target="_blank">GitHub Issue Tracker</a>.

## Supported platforms

**mehen** can run on the most common platforms: Linux, macOS,
and Windows.

On our
<a href="https://github.com/ophidiarium/mehen/releases" target="_blank">GitHub Release Page</a>
you can find the `Linux` and `Windows` binaries already compiled and
packed for you.


## License

**mehen** is released under the
<a href="https://www.mozilla.org/MPL/2.0/" target="_blank">Mozilla Public License v2.0</a>.
